@@ -1,8 +1,6 @@
-
-
 -- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 -- 
--- $Id: topology.sql.in 2469 2006-09-06 11:16:59Z strk $
+-- $Id: topology.sql.in.c 3687 2009-02-11 18:28:53Z pramsey $
 --
 -- PostGIS - Spatial Types for PostgreSQL
 -- http://postgis.refractions.net
@@ -164,6 +162,23 @@
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 DROP SCHEMA topology CASCADE;
@@ -194,7 +209,7 @@ CREATE TABLE topology.topology (
 --
 -- Layer integrity trigger
 --
-CREATE OR REPLACE FUNCTION topology.LayerTrigger()
+CREATEFUNCTION topology.LayerTrigger()
 	RETURNS trigger
 AS
 '
@@ -270,7 +285,7 @@ BEGIN
 	RETURN OLD;
 END;
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 --} LayerTrigger()
 
 
@@ -357,7 +372,7 @@ CREATE DOMAIN topology.TopoGeomElementArray AS integer[][]
 --
 -- Relation integrity trigger
 --
-CREATE OR REPLACE FUNCTION topology.RelationTrigger()
+CREATEFUNCTION topology.RelationTrigger()
 	RETURNS trigger
 AS
 '
@@ -502,7 +517,7 @@ BEGIN
 	RETURN NEW;
 END;
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 --} RelationTrigger()
 
 --{
@@ -512,7 +527,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT;
 --  Returns created layer id.
 --
 --
-CREATE OR REPLACE FUNCTION topology.AddTopoGeometryColumn(varchar, varchar, varchar, varchar, varchar, integer)
+CREATEFUNCTION topology.AddTopoGeometryColumn(varchar, varchar, varchar, varchar, varchar, integer)
 	RETURNS integer
 AS '
 DECLARE
@@ -651,14 +666,14 @@ BEGIN
 	RETURN layer_id;
 END;
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 
-CREATE OR REPLACE FUNCTION topology.AddTopoGeometryColumn(varchar, varchar, varchar, varchar, varchar)
+CREATEFUNCTION topology.AddTopoGeometryColumn(varchar, varchar, varchar, varchar, varchar)
 	RETURNS integer
 AS '
 	SELECT topology.AddTopoGeometryColumn($1, $2, $3, $4, $5, NULL);
 '
-LANGUAGE 'sql' VOLATILE;
+LANGUAGE 'sql' _VOLATILE;
 
 --
 --} AddTopoGeometryColumn
@@ -670,7 +685,7 @@ LANGUAGE 'sql' VOLATILE;
 --  cleanup the relation table.
 --
 --
-CREATE OR REPLACE FUNCTION topology.DropTopoGeometryColumn(varchar, varchar, varchar)
+CREATEFUNCTION topology.DropTopoGeometryColumn(varchar, varchar, varchar)
 	RETURNS text
 AS '
 DECLARE
@@ -759,7 +774,7 @@ BEGIN
 	RETURN result;
 END;
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --
 --} DropTopoGeometryColumn
 
@@ -777,7 +792,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 -- 
 -- Return a topology.TopoGeometry object.
 --
-CREATE OR REPLACE FUNCTION topology.CreateTopoGeom(varchar, integer, integer, topology.TopoElementArray)
+CREATEFUNCTION topology.CreateTopoGeom(varchar, integer, integer, topology.TopoElementArray)
 	RETURNS topology.TopoGeometry
 AS '
 DECLARE
@@ -885,13 +900,13 @@ BEGIN
 
 END
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 --} CreateTopoGeom(toponame,topogeom_type, TopoObject[])
 
 --{
 -- GetTopologyName(topology_id)
 --
-CREATE OR REPLACE FUNCTION topology.GetTopologyName(integer)
+CREATEFUNCTION topology.GetTopologyName(integer)
 	RETURNS varchar
 AS
 '
@@ -904,13 +919,13 @@ BEGIN
 	RETURN ret;
 END
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 --} GetTopologyName(topoid)
 
 --{
 -- GetTopologyId(toponame)
 --
-CREATE OR REPLACE FUNCTION topology.GetTopologyId(varchar)
+CREATEFUNCTION topology.GetTopologyId(varchar)
 	RETURNS integer
 AS
 '
@@ -923,7 +938,7 @@ BEGIN
 	RETURN ret;
 END
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 --} GetTopologyId(toponame)
 	
 
@@ -934,7 +949,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT;
 --
 -- Returns a set of element_id,element_type
 --
-CREATE OR REPLACE FUNCTION topology.GetTopoGeomElementArray(varchar, integer, integer)
+CREATEFUNCTION topology.GetTopoGeomElementArray(varchar, integer, integer)
 	RETURNS topology.TopoElementArray
 AS
 '
@@ -973,9 +988,9 @@ BEGIN
 	RETURN tg_objs;
 END;
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 
-CREATE OR REPLACE FUNCTION topology.GetTopoGeomElementArray(topology.TopoGeometry)
+CREATEFUNCTION topology.GetTopoGeomElementArray(topology.TopoGeometry)
 	RETURNS topology.TopoElementArray
 AS
 '
@@ -989,7 +1004,7 @@ BEGIN
 	RETURN ret;
 END;
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 
 --} GetTopoGeomElementArray()
 
@@ -999,7 +1014,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT;
 --
 -- Returns a set of element_id,element_type
 --
-CREATE OR REPLACE FUNCTION topology.GetTopoGeomElements(varchar, integer, integer)
+CREATEFUNCTION topology.GetTopoGeomElements(varchar, integer, integer)
 	RETURNS SETOF topology.TopoElement
 AS
 '
@@ -1063,9 +1078,9 @@ BEGIN
 	RETURN;
 END;
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 
-CREATE OR REPLACE FUNCTION topology.GetTopoGeomElements(topology.TopoGeometry)
+CREATEFUNCTION topology.GetTopoGeomElements(topology.TopoGeometry)
 	RETURNS SETOF topology.TopoElement
 AS
 '
@@ -1083,7 +1098,7 @@ BEGIN
 	RETURN;
 END;
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 
 --} GetTopoGeomElements()
 
@@ -1216,7 +1231,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT;
 --  Return a Set of ValidateTopology_ReturnType containing
 --  informations on all topology inconsistencies
 --
-CREATE OR REPLACE FUNCTION topology.ValidateTopology(varchar)
+CREATEFUNCTION topology.ValidateTopology(varchar)
 	RETURNS setof topology.ValidateTopology_ReturnType
 AS
 '
@@ -1363,7 +1378,7 @@ BEGIN
 	RETURN;
 END
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 -- } ValidateTopology(toponame)
 
 --{
@@ -1371,7 +1386,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT;
 --
 --  Add a Point (node) into a topology 
 --
-CREATE OR REPLACE FUNCTION topology.TopoGeo_AddPoint(varchar, geometry, integer, integer)
+CREATEFUNCTION topology.TopoGeo_AddPoint(varchar, geometry, integer, integer)
 	RETURNS int AS
 '
 DECLARE
@@ -1389,7 +1404,7 @@ BEGIN
 
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} TopoGeo_AddPoint
 
 --{
@@ -1397,7 +1412,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  Add a Point (node) into a topology 
 --
-CREATE OR REPLACE FUNCTION topology.TopoGeo_addLinestring(varchar, geometry)
+CREATEFUNCTION topology.TopoGeo_addLinestring(varchar, geometry)
 	RETURNS int AS
 '
 DECLARE
@@ -1437,7 +1452,7 @@ LANGUAGE 'plpgsql';
 --
 --  Add a Polygon into a topology 
 --
-CREATE OR REPLACE FUNCTION topology.TopoGeo_AddPolygon(varchar, geometry)
+CREATEFUNCTION topology.TopoGeo_AddPolygon(varchar, geometry)
 	RETURNS int AS
 '
 DECLARE
@@ -1458,7 +1473,7 @@ LANGUAGE 'plpgsql';
 -- in the topology.topology relation, return it's numeric
 -- id. 
 --
-CREATE OR REPLACE FUNCTION topology.CreateTopology(varchar, integer, float8)
+CREATEFUNCTION topology.CreateTopology(varchar, integer, float8)
 RETURNS integer
 AS '
 DECLARE
@@ -1639,19 +1654,19 @@ CREATE SCHEMA '' || quote_ident(atopology) || '';
 	RETURN topology_id;
 END
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 
 -- wrappers for unspecified srid or precision
 
-CREATE OR REPLACE FUNCTION topology.CreateTopology(varchar, integer)
+CREATEFUNCTION topology.CreateTopology(varchar, integer)
 RETURNS integer AS
 ' SELECT topology.CreateTopology($1, $2, -1); '
-LANGUAGE 'SQL' VOLATILE STRICT;
+LANGUAGE 'SQL' _VOLATILE_STRICT;
 
-CREATE OR REPLACE FUNCTION topology.CreateTopology(varchar)
+CREATEFUNCTION topology.CreateTopology(varchar)
 RETURNS integer AS
 ' SELECT topology.CreateTopology($1, -1, -1); '
-LANGUAGE 'SQL' VOLATILE STRICT;
+LANGUAGE 'SQL' _VOLATILE_STRICT;
 
 --} CreateTopology
 
@@ -1660,7 +1675,7 @@ LANGUAGE 'SQL' VOLATILE STRICT;
 --
 -- Drops a topology schema getting rid of every dependent object.
 --
-CREATE OR REPLACE FUNCTION topology.DropTopology(varchar)
+CREATEFUNCTION topology.DropTopology(varchar)
 RETURNS text
 AS '
 DECLARE
@@ -1710,7 +1725,7 @@ BEGIN
 	RETURN ''Topology '' || quote_literal(atopology) || '' dropped'';
 END
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 --} DropTopology
 
 --={ ----------------------------------------------------------------
@@ -1723,7 +1738,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT;
 --{
 -- Intersects(TopoGeometry, TopoGeometry)
 --
-CREATE OR REPLACE FUNCTION topology.intersects(topology.TopoGeometry, topology.TopoGeometry)
+CREATEFUNCTION topology.intersects(topology.TopoGeometry, topology.TopoGeometry)
 	RETURNS bool
 AS
 '
@@ -2148,13 +2163,13 @@ BEGIN
 	END IF;
 END
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 --} intersects(TopoGeometry, TopoGeometry)
 
 --{
 --  equals(TopoGeometry, TopoGeometry)
 --
-CREATE OR REPLACE FUNCTION topology.equals(topology.TopoGeometry, topology.TopoGeometry)
+CREATEFUNCTION topology.equals(topology.TopoGeometry, topology.TopoGeometry)
 	RETURNS bool
 AS
 '
@@ -2212,7 +2227,7 @@ BEGIN
 	RETURN TRUE;
 END
 '
-LANGUAGE 'plpgsql' VOLATILE STRICT;
+LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 --} equals(TopoGeometry, TopoGeometry)
 
 --=} POSTGIS-SPECIFIC topology predicates
@@ -2236,7 +2251,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT;
 --
 --
 -- 
-CREATE OR REPLACE FUNCTION topology.ST_GetFaceEdges(varchar, integer)
+CREATEFUNCTION topology.ST_GetFaceEdges(varchar, integer)
 	RETURNS setof topology.GetFaceEdges_ReturnType
 AS
 '
@@ -2259,7 +2274,7 @@ BEGIN
 
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_GetFaceEdges
 
 
@@ -2269,7 +2284,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_GetFaceGeometry(atopology, aface)
 -- 
-CREATE OR REPLACE FUNCTION topology.ST_GetFaceGeometry(varchar, integer)
+CREATEFUNCTION topology.ST_GetFaceGeometry(varchar, integer)
 	RETURNS GEOMETRY AS
 '
 DECLARE
@@ -2305,7 +2320,7 @@ BEGIN
 	''SQL/MM Spatial exception - non-existent face.'';
 END
 ' 
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_GetFaceGeometry
 
 
@@ -2315,7 +2330,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_AddIsoNode(atopology, aface, apoint)
 --
-CREATE OR REPLACE FUNCTION topology.ST_AddIsoNode(varchar, integer, geometry)
+CREATEFUNCTION topology.ST_AddIsoNode(varchar, integer, geometry)
 	RETURNS INTEGER AS
 '
 DECLARE
@@ -2369,7 +2384,7 @@ BEGIN
 		|| '')''
 	LOOP
 		RAISE EXCEPTION
-		''SQL/MM Spatial exception  edge crosses node.'';
+		''SQL/MM Spatial exception - edge crosses node.'';
 	END LOOP;
 
 
@@ -2423,7 +2438,7 @@ BEGIN
 	RETURN nodeid;
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_AddIsoNode
 
 --{
@@ -2432,7 +2447,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_MoveIsoNode(atopology, anode, apoint)
 --
-CREATE OR REPLACE FUNCTION topology.ST_MoveIsoNode(varchar, integer, geometry)
+CREATEFUNCTION topology.ST_MoveIsoNode(varchar, integer, geometry)
 	RETURNS TEXT AS
 '
 DECLARE
@@ -2497,7 +2512,7 @@ BEGIN
 		|| '')''
 	LOOP
 		RAISE EXCEPTION
-		''SQL/MM Spatial exception  edge crosses node.'';
+		''SQL/MM Spatial exception - edge crosses node.'';
 	END LOOP;
 
 	--
@@ -2511,7 +2526,7 @@ BEGIN
 		|| x(apoint) || '','' || y(apoint);
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_MoveIsoNode
 
 --{
@@ -2520,7 +2535,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_RemoveIsoNode(atopology, anode)
 --
-CREATE OR REPLACE FUNCTION topology.ST_RemoveIsoNode(varchar, integer)
+CREATEFUNCTION topology.ST_RemoveIsoNode(varchar, integer)
 	RETURNS TEXT AS
 '
 DECLARE
@@ -2555,7 +2570,7 @@ BEGIN
 	RETURN ''Isolated node '' || anode || '' removed'';
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_RemoveIsoNode
 
 --{
@@ -2564,7 +2579,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_RemoveIsoEdge(atopology, anedge)
 --
-CREATE OR REPLACE FUNCTION topology.ST_RemoveIsoEdge(varchar, integer)
+CREATEFUNCTION topology.ST_RemoveIsoEdge(varchar, integer)
 	RETURNS TEXT AS
 '
 DECLARE
@@ -2628,7 +2643,7 @@ BEGIN
 	RETURN ''Isolated edge '' || anedge || '' removed'';
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_RemoveIsoEdge
 
 --{
@@ -2637,7 +2652,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_NewEdgesSplit(atopology, anedge, apoint)
 --
-CREATE OR REPLACE FUNCTION topology.ST_NewEdgesSplit(varchar, integer, geometry)
+CREATEFUNCTION topology.ST_NewEdgesSplit(varchar, integer, geometry)
 	RETURNS INTEGER AS
 '
 DECLARE
@@ -2881,7 +2896,7 @@ BEGIN
 	RETURN nodeid; 
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_NewEdgesSplit
 
 --{
@@ -2890,7 +2905,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_ModEdgesSplit(atopology, anedge, apoint)
 --
-CREATE OR REPLACE FUNCTION topology.ST_ModEdgesSplit(varchar, integer, geometry)
+CREATEFUNCTION topology.ST_ModEdgesSplit(varchar, integer, geometry)
 	RETURNS INTEGER AS
 '
 DECLARE
@@ -3087,7 +3102,7 @@ BEGIN
 	RETURN nodeid; 
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_ModEdgesSplit
 
 --{
@@ -3096,7 +3111,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_AddIsoEdge(atopology, anode, anothernode, acurve)
 -- 
-CREATE OR REPLACE FUNCTION topology.ST_AddIsoEdge(varchar, integer, integer, geometry)
+CREATEFUNCTION topology.ST_AddIsoEdge(varchar, integer, integer, geometry)
 	RETURNS INTEGER AS
 '
 DECLARE
@@ -3216,7 +3231,7 @@ BEGIN
 		--
 		IF ! within(acurve, face) THEN
 	RAISE EXCEPTION
-	''SQL/MM Spatial exception  geometry not within face.'';
+	''SQL/MM Spatial exception - geometry not within face.'';
 		END IF;
 
 	END IF;
@@ -3228,7 +3243,7 @@ BEGIN
 	IF x(snodegeom) != x(StartPoint(acurve)) OR
 	   y(snodegeom) != y(StartPoint(acurve)) THEN
   RAISE EXCEPTION
-  ''SQL/MM Spatial exception  start node not geometry start point.'';
+  ''SQL/MM Spatial exception - start node not geometry start point.'';
 	END IF;
 
 	--
@@ -3238,7 +3253,7 @@ BEGIN
 	IF x(enodegeom) != x(EndPoint(acurve)) OR
 	   y(enodegeom) != y(EndPoint(acurve)) THEN
   RAISE EXCEPTION
-  ''SQL/MM Spatial exception  end node not geometry end point.'';
+  ''SQL/MM Spatial exception - end node not geometry end point.'';
 	END IF;
 
 	--
@@ -3292,7 +3307,7 @@ BEGIN
 
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_AddIsoEdge
 
 --{
@@ -3301,7 +3316,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_ChangeEdgeGeom(atopology, anedge, acurve)
 -- 
-CREATE OR REPLACE FUNCTION topology.ST_ChangeEdgeGeom(varchar, integer, geometry)
+CREATEFUNCTION topology.ST_ChangeEdgeGeom(varchar, integer, geometry)
 	RETURNS TEXT AS
 '
 DECLARE
@@ -3422,7 +3437,7 @@ BEGIN
 
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_ChangeEdgeGeom
 
 --{
@@ -3431,7 +3446,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_AddEdgeNewFaces(atopology, anode, anothernode, acurve)
 --
-CREATE OR REPLACE FUNCTION topology.ST_AddEdgeNewFaces(varchar, integer, integer, geometry)
+CREATEFUNCTION topology.ST_AddEdgeNewFaces(varchar, integer, integer, geometry)
 	RETURNS INTEGER AS
 '
 DECLARE
@@ -3627,7 +3642,7 @@ BEGIN
 	RAISE EXCEPTION ''Not implemented yet'';
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_AddEdgeNewFaces
 
 --{
@@ -3636,7 +3651,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_InitTopoGeo(atopology)
 --
-CREATE OR REPLACE FUNCTION topology.ST_InitTopoGeo(varchar)
+CREATEFUNCTION topology.ST_InitTopoGeo(varchar)
 RETURNS text
 AS '
 DECLARE
@@ -3663,7 +3678,7 @@ BEGIN
 		|| '' (id:'' || topology_id || '') created. '';
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_InitTopoGeo
 
 --{
@@ -3672,7 +3687,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 --
 --  ST_CreateTopoGeo(atopology, acollection)
 --
-CREATE OR REPLACE FUNCTION topology.ST_CreateTopoGeo(varchar, geometry)
+CREATEFUNCTION topology.ST_CreateTopoGeo(varchar, geometry)
 RETURNS text
 AS '
 DECLARE
@@ -3759,7 +3774,7 @@ BEGIN
 	RAISE EXCEPTION ''ST_CreateTopoGeo not implemente yet'';
 END
 '
-LANGUAGE 'plpgsql' VOLATILE;
+LANGUAGE 'plpgsql' _VOLATILE;
 --} ST_CreateTopoGeo
 
 --=}  SQL/MM block
