@@ -1,11 +1,11 @@
 #!/bin/bash
 # PostGIS	(http://postgis.refractions.net/)
-VERSION=1.3.6
+VERSION=1.4.0
 VER=${VERSION%%.?}
-#	BuildScript for Plamo Linux 4.6
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-08-21
+#	BuildScript for Plamo Linux 4.7
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-08-31
 # require:
-PGVERSION=8.3.7
+PGVERSION=8.4.0
 POSTGRESQL=postgresql-$PGVERSION
 GEOS=geos-3.1.1
 PROJ=proj-4.6.1
@@ -13,6 +13,7 @@ PROJ=proj-4.6.1
 PAC_NAME=postgis-$VERSION
 SRC_FILE=${PAC_NAME}.tar.gz
 SRC_URI=http://postgis.refractions.net/download/$SRC_FILE
+#       http://postgis.refractions.net/download/postgis-1.4.0.tar.gz
 
 
 REL=P1
@@ -21,7 +22,7 @@ SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 SRC_DIR=$PLAMO/Archive/dbms/pgsql
-PAC_DIR=$PLAMO/Packages/4.6/10_gis/
+PAC_DIR=$PLAMO/Packages/4.7/10_gis/
 BUILD_DIR=$PLAMO/postgis
 CUSTOM_DIR=$BUILD_DIR/Custom
 PAT_FILE=
@@ -63,13 +64,13 @@ tar xvfz  $SRC_DIR/$SRC_FILE
 cd $PAC_NAME
   PREFIX=/opt/pgsql
   ./configure --prefix=$PREFIX \
-      --with-pgsql=$PREFIX/bin/pg_config \
       --datadir=$PREFIX/share/contrib \
-      --with-geos=/usr/bin/geos-config \
-      --with-proj=/usr \
+      --with-pgconfig=$PREFIX/bin/pg_config \
+      --with-projdir=/usr \
+      --with-geosconfig=/usr/bin/geos-config \
       || exit 1
 
- # USE_PROJ=1 PROJ_DIR=/usr USE_GEOS=1 GEOS_DIR=/usr  make
+ #USE_PROJ=1 PROJ_DIR=/usr USE_GEOS=1 GEOS_DIR=/usr  make
  make install DESTDIR=$WORK
  cd topology
  make install DESTDIR=$WORK
@@ -77,15 +78,13 @@ cd $PAC_NAME
  cd doc
  make install DESTDIR=$WORK
  cd ..
-  perl utils/create_undef.pl  lwpostgis.sql $PGVERSION > lwpostgis_undef.sql
-  cp lwpostgis_undef.sql $WORK/$PREFIX/share/contrib/
 
  # regression test
- cd regress/
- chown -R postgres .
- su postgres -c make > regress-make.log
- mv regress-make.log $CUSTOM_DIR
- cd ..
+ #cd regress/
+ #chown -R postgres .
+ #su postgres -c make > regress-make.log
+ #mv regress-make.log $CUSTOM_DIR
+ #cd ..
 
 DOC_DIR=usr/share/doc/$PAC_NAME
 mkdir -p $WORK/$DOC_DIR || exit 1
@@ -101,22 +100,27 @@ chmod -R a+rX $WORK/$DOC_DIR
 
 # make package
 cd $WORK
+ mv opt/$POSTGRESQL opt/pgsql
+
+ tar cf - \
+    $PREFIX/share/doc/postgis/ \
+    $PREFIX/share/man/man1/pgsql2shp.1 \
+    $PREFIX/share/man/man1/shp2pgsql.1 \
+  | tar xvf -
+
  mkdir install
  sed -e "s/_VER_/$VER/" \
+     -e "s/_PAC_NAME_/$PAC_NAME/" \
      -e "s/_PACKAGENAME_/${PAC_NAME}-${SYS_NAME}/" \
-     $CUSTOM_DIR/doinst.sh-1.3 > install/doinst.sh
- cp -p $CUSTOM_DIR/lwpostgis-install.sh opt/pgsql/share/contrib/
- cp -p $CUSTOM_DIR/lwpostgis-upgrade.sh opt/pgsql/share/contrib/
- cp -p $CUSTOM_DIR/lwpostgis-uninstall.sh opt/pgsql/share/contrib/
- cp opt/pgsql/share/contrib/lwpostgis_undef.sql $CUSTOM_DIR/undef/lwpostgis_undef.sql-${VERSION}
-  chown -R postgres:pgsql opt/pgsql
+     $CUSTOM_DIR/doinst.sh-1.4 > install/doinst.sh
+ cp -p $CUSTOM_DIR/postgis-install.sh $DOC_DIR
+ cp -p $CUSTOM_DIR/postgis-upgrade.sh $DOC_DIR
+ cp -p $CUSTOM_DIR/postgis-uninstall.sh $DOC_DIR
+ chown -R postgres:pgsql opt/pgsql
 
- rm -f ./opt/pgsql/bin/createdb.postgis
- rm -f ./opt/pgsql/bin/mktemplate_gis
- rm -f ./opt/pgsql/bin/rmtemplate_gis
 
   tar cvfz ../${PAC_NAME}-${SYS_NAME}.tgz \
-    opt/pgsql/{bin,lib,doc}/* opt/pgsql/man/*/* opt/pgsql/share/contrib/* usr/share/doc/${PAC_NAME}/ install/doinst.sh
+    opt/pgsql/{bin,lib}/* opt/pgsql/share/man/*/* opt/pgsql/share/contrib/* usr/share/doc/${PAC_NAME}/ install/doinst.sh
   mv -v ../${PAC_NAME}-${SYS_NAME}.tgz $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz
   ls -l $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz
 
